/***************************************************************************
 *                                                                         *
 * Copyright (c) 1996 Net-Scene Inc.  All Rights Reserved.                 *
 * Permission to use, copy, modify, and distribute this software	   *
 * and its documentation for NON-COMMERCIAL or COMMERCIAL purposes and	   *
 * without fee is hereby granted. 					   *
 *                                                                         *
 ***************************************************************************
 *  File Name      : PPMain.java					   *
 *  Project        : A simple example - getting connected to PointPlus	   *
 *  Written By     : Oded Cna'an    (OC)                                   *
 *  Language       : Java                                                  *
 ***************************************************************************
 *      Creation   :  OC   16 Jun 96    1:14 pm                            *
	Last change:  OC   27 Jun 96   11:09 am
 ***************************************************************************/
 
import PPApplet;
import netscape.javascript.JSObject;
import netscape.javascript.JSException;
import java.util.*;
import java.awt.*;
import java.lang.*;
import java.applet.Applet;

//**************************************************************************
//  Class name  : PPMain
//  Description : a simple example
//**************************************************************************
public class PPMain extends Applet implements PPApplet {

private String title = null;
private Controls controls;

	//--------------------------------------------------------------------------
	//  Function name  : init
	//  Description    : get parameters from html
	//--------------------------------------------------------------------------
	public void init() {
	    title = getParameter("title");
	    title = (title == null) ? "Simple example - Connecting to PointPlus" : title;
	    setLayout(new BorderLayout());
	}

	//--------------------------------------------------------------------------
	//  Function name  : start
	//  Description    : create the controls. passes the 'Controls' class a 
	//  pointer to the document.
	//--------------------------------------------------------------------------
	public void start() {
	    removeAll();
	    add("Center",controls = new Controls(getDocument()));
	} //end of function start

	//--------------------------------------------------------------------------
	//  Function name  : stop
	//  Description    : when reloading, the connection must be created again
	//--------------------------------------------------------------------------
	public void stop() {
	     controls.resetConnected();
	} //end of function stop

	//--------------------------------------------------------------------------
	//  Function name  : getDocument
	//  Description    : returns a pointer to the document
	//--------------------------------------------------------------------------
	public JSObject getDocument() {
	   	return (JSObject)JSObject.getWindow(this).getMember("document");
	} //end of function getDocument
} //end of class PPMain



//**************************************************************************
//  Class name  : Controls
//  Description : Create the interface and respond to events
//**************************************************************************
class Controls extends Panel {

private JSObject 	doc;
private boolean  	connected;
private Button   	startBt,stopBt;
private TextField 	text,from,to;
private int 		totSlides;
private int     	state;
private final String 	START     = "Start";
private final String 	STOP      = "Stop";
private final int    	RUNNING   = 1;
private final int    	READY     = 2;


private PPSender ppSender;
private PPReceiver ppReceive;

	//--------------------------------------------------------------------------
	//  Function name  : Controls
	//  Description    : Constructor
	//--------------------------------------------------------------------------
	public Controls(JSObject doc) {
		this.doc = doc;			// save the document for future use
		connected = false;
		totSlides = 0;
                setLayout(new BorderLayout());
		setBackground(Color.white);

		// add text field
		add("North",text = new TextField(30));
		text.setEditable(false);
		text.setBackground(Color.blue);
		text.setForeground(Color.white);

		// add info areas
		Panel inf = new Panel();
		inf.setLayout(new GridLayout(4,30));
		inf.add(new Label("Messages sent to PointPlus : "));
		inf.add(to = new TextField(30));
		inf.add(new Label("Messages received from PointPlus : "));
		inf.add(from = new TextField(30));
		add("Center",inf);
		to.setEditable(false);
		to.setBackground(Color.blue);
		to.setForeground(Color.white);
		from.setEditable(false);
		from.setBackground(Color.blue);
		from.setForeground(Color.white);

		// add some buttons
		Panel p = new Panel();
		p.setLayout(new GridLayout(2,30));
		p.add(startBt = new Button(START));
		p.add(stopBt = new Button(STOP));
		add("South",p);

		state = READY;
	        // connection is opened just once
		// unless after reload
	        if ( !connected ) {
			ppReceive = new PPReceiver(this);
			// the string "css" is the name of the embedded plugin
			// as defined in the HTML file
			PPPlugin css = (PPPlugin)doc.getMember("css");
			ppSender = new PPSender(ppReceive,PPSender.C_PP_SEND,css);
			connected = true;  // mark it as connected
	        }
                to.setText("Asking PointPlus to stop at the first slide");
                ppSender.SendPointPlus(ppSender.GO_FIRST_SLIDE,0," ");
	        text.setText("Connection established. Press start to see the show.");
	}

	//--------------------------------------------------------------------------
	//  Function name  : action
	//  Description    : event handler for buttons
	//--------------------------------------------------------------------------
        public boolean action(Event evt, Object arg) {
			// help button
		if ( START.equals(arg) ) {
		    onStart();
		    return true;
		}
		else if ( STOP.equals(arg) ) {
		    onStop();
		    return true;
		}
		else
		    return false;

	} //end of function action

	//--------------------------------------------------------------------------
	//  Function name  : onStart
	//  Description    : 
	//--------------------------------------------------------------------------
	private void onStart() {
	       state = RUNNING;
               to.setText("Asking PointPlus to play the show from the beginning");
               ppSender.SendPointPlus(ppSender.PLAY_FROM_SLIDE,1," ");
               totSlides = ppSender.SendPointPlus(ppSender.GET_TOT_SLIDE_NUM,0," ");
	       from.setText("total number of slide is "+totSlides);
	       text.setText("Starting show");
	} //end of function onStart

	//--------------------------------------------------------------------------
	//  Function name  : onStop
	//  Description    : 
	//--------------------------------------------------------------------------
	private void onStop() {
	       state = READY;
	       to.setText("Asking PointPlus to stop the show");
               ppSender.SendPointPlus(ppSender.PAUSE_SHOW,0," ");
	       text.setText("Show stopped");
	} //end of function onStop

	//--------------------------------------------------------------------------
	//  Function name  : onSlideChangeMsg
	//  Description    : 
	//--------------------------------------------------------------------------
	public void onSlideChangeMsg(int currSlide) {
	    if ( state == RUNNING )
		    from.setText("Current Slide is "+currSlide+"   out of "+totSlides+"  slides");
	} //end of function onSlideChangeMsg

	//--------------------------------------------------------------------------
	//  Function name  : resetConnected
	//  Description    : 
	//--------------------------------------------------------------------------
	public void resetConnected() {
	    connected = false;
	} //end of function resetConnected

} //end of class Controls
